;============================================================================;
; File: SCI12.A
; Func: Serial-I/O via the Serial Communication Interface (SCI0)
;============================================================================;

;	CPU 68HC12
	include "Z:\mpp_protokoll\reghc12.inc"


SC0BD	equ SC0BDH 		;==>das entsprechende Register fr das Festlegen der Baudrate
SC0CR	equ SC0CR1		;==> dieses Register fr die Initialisierung der Schnittstelle

;Die zu bertragenden Daten stehen immer im SC0DRL Register. Man kann nur 8 bits senden oder empfangen.
;Bevor man ins Register schreibt, muss man prfen, ob man noch im Transmit-Modus ist und senden kann.
;Dies erkennt man am Bit 7 vom Register SC0SR1.
;Frs Empfangen hat man analog Bit 5 dieses Registers zur Verfgung.

;--- Memory Definitions ---
RAM_DATEN:	EQU $2000	;start of RAM variables
RAM_PROG:	EQU $3000
RAM_END:	EQU $4000


	ORG     RAM_PROG	;start

	lds 	#RAM_END
	clr	COPCTL		;clear Watchdog
	jsr	initSCI	
	ldaa	#65
L1:	jsr	putSCI
	jsr	getSCI
		bra L1;

; Func:	Initialize SCI (9600 Baud, 8N1, Polling Mode)
; Args:	-
; Retn: -
; Dest: D
;
initSCI		ldd   #26		; 19200 Bd
		std   SC0BD
		ldd   #$000c		; 8N1, TE + RE, TE:= bermittelung der Daten ber die Schnittstelle nach auen
					; RE:=damit empfangen werden kann
		std   SC0CR		; A:B -> SC0CR1:SC0CR2
	        rts


; Func:	Test if any character available (received)
; Args:	-
; Retn: A =  0 (Z = 1) -> no char
;	A <> 0 (Z = 0) -> char available
; Dest: -
;
testSCI		ldaa  SC0SR1		; read status
	        anda  #$20		; receive data reg full?
        	rts                     ; returns 0, if no data


; Func:	Get character from SCI (wait for)
; Args:	-
; Retn: A = char
; Dest: -
;
getSCI		brclr SC0SR1,$20,getSCI	; receive data reg full?
	        ldaa  SC0DRL		; read out data
        	rts


; Func:	Send a character via SCI
; Args:	A = char
; Retn: -
; Dest: -
;
putSCI		brclr SC0SR1,$80,putSCI	; transmit data reg empty?
        	staa  SC0DRL		; send data
	        rts


