;============================================================================;
; File: SCI12.A
; Func: Serial-I/O via the Serial Communication Interface (SCI0)
;============================================================================;

;	CPU 68HC12   FFD6,FFD7 fr SCI0 Interrupt
;		     FFCE,FFCF fr Key Wake up J or H
DDRB:  EQU $0003
PORTB: EQU $0001
PUCR:	EQU $000C
COPCTL: EQU $0016
DDRH:	EQU $002B
PORTH:	EQU $0029

SC0BDH	equ	$00c0	; [A|B] SCI 0 Baud Rate Control Register High
SC0BDL	equ	$00c1	; [A|B] SCI 0 Baud Rate Control Register Low
SC0CR1	equ	$00c2	; [A|B] SCI 0 Control Register 1
SC0CR2	equ	$00c3	; [A|B] SCI 0 Control Register 2
SC0SR1	equ	$00c4	; [A|B] SCI 0 Status Register 1
SC0SR2	equ	$00c5	; [A|B] SCI 0 Status Register 2
SC0DRH	equ	$00c6	; [A|B] SCI 0 Data Register High
SC0DRL	equ	$00c7	; [A|B] SCI 0 Data Register Low

SP0CR1	equ	$00d0	; [A|B] SPI Control Register 1
SP0CR2	equ	$00d1	; [A|B] SPI Control Register 2
SP0BR	equ	$00d2	; [A|B] SPI Baud Rate Register
SP0SR	equ	$00d3	; [A|B] SPI Status Register

SC0BD	equ SC0BDH 		;==>das entsprechende Register fr das Festlegen der Baudrate
SC0CR	equ SC0CR1		;==> dieses Register fr die Initialisierung der Schnittstelle
KWPH	equ $0031
KWIEH	equ $002D
KWIFH	equ $002F

;Die zu bertragenden Daten stehen immer im SC0DRL Register. Man kann nur 8 bits senden oder empfangen.
;Bevor man ins Register schreibt, muss man prfen, ob man noch im Transmit-Modus ist und senden kann.
;Dies erkennt man am Bit 7 vom Register SC0SR1.
;Frs Empfangen hat man analog Bit 5 dieses Registers zur Verfgung.

;--- Memory Definitions ---
RAM_DATEN:	EQU $2000	;start of RAM variables
RAM_PROG:	EQU $3000
RECEIVED_CHAR	EQU $3300	;start von 1.Subroutine zum Abprfen des Characters
WAKE_UP		EQU $3500	;start von 2.Subroutine zum berprfuen des Zustandes beim Port H
RAM_END:	EQU $4000


	ORG     RAM_PROG	;start

	lds 	#RAM_END
	clr	COPCTL		;clear Watchdog
	movb	#$FF, DDRB
	movb	#$00, DDRH
	jsr	initSCI	
	
	ldaa	PUCR			; Initialize PupH
	oraa	#$20			; set the 5th Bit
	staa	PUCR
	
	movb	#$FF, KWIEH	; Enable all Key-Wake-up- Interrupts of Port H
	movb	#$00, KWPH	; Interrupt at falling edge
	cli			;Interrupt ist mglich
L1:	jmp	L1
	
			
	ORG	RECEIVED_CHAR
	jsr	getSCI
	nega
	staa	PORTB
	cmpa	#$C1
	bne	NOT_EQ
	ldaa	PORTH
	jsr	putSCI
NOT_EQ:	rti

	ORG	WAKE_UP
	ldaa	PORTH
	jsr	putSCI
	rti
	
	

; Func:	Initialize SCI (9600 Baud, 8N1, Polling Mode)
; Args:	-
; Retn: -
; Dest: D
;
initSCI		ldd   #26		; 19200 Bd
		std   SC0BD
		ldd   #$002c		; 8N1, TE + RE, TE:= bermittelung der Daten ber die Schnittstelle nach auen
					; RE:=damit empfangen werden kann
       				  	; wir setzen auch Bit 5, damit der Receiver Interrupt "enabled" wird
		std   SC0CR		; A:B -> SC0CR1:SC0CR2
	        rts


; Func:	Test if any character available (received)
; Args:	-
; Retn: A =  0 (Z = 1) -> no char
;	A <> 0 (Z = 0) -> char available
; Dest: -
;
testSCI		ldaa  SC0SR1		; read status
	        anda  #$20		; receive data reg full?
        	rts                     ; returns 0, if no data


; Func:	Get character from SCI (wait for)
; Args:	-
; Retn: A = char
; Dest: -
;
getSCI		brclr SC0SR1,$20,getSCI	; receive data reg full?
	        ldaa  SC0DRL		; read out data
        	rts


; Func:	Send a character via SCI
; Args:	A = char
; Retn: -
; Dest: -
;
putSCI		brclr SC0SR1,$80,putSCI	; transmit data reg empty?
        	staa  SC0DRL		; send data
	        rts


